@@ -4,8 +4,9 @@ use warnings;
 use strict;
 use 5.008;
 use Carp;
+use Scalar::Util 'refaddr';
 
-our $VERSION = '0.051000';
+our $VERSION = '0.051004';
 
 # Exports only the slurp() sub...
 sub import {
@@ -21,7 +22,7 @@ my $mode_pat = qr{
 # Recognize a mode followed by optional layer arguments...
 my $mode_plus_layers = qr{
     (?: $mode_pat | ^ \s* -\| \s* )
-    ( (?: :[^\W\d]\w* \s* )* )
+    ( (?: :[^\W\d]\w* (?: \( .*? \) ?)? \s* )* )
     \s*
     \z
 }x;
@@ -111,7 +112,7 @@ sub slurp {
     # This track the various options slurp() allows...
     my ($chomp, $chomp_to, $layers) = (0, "", "");
 
-    # Can this slurp be done in an optimized way (assume so initally)???
+    # Can this slurp be done in an optimized way (assume so initially)???
     my $optimized = 1;
 
     # Decode the layers and options...
@@ -139,7 +140,7 @@ sub slurp {
         $layers .= join " ", map ":$_", keys %$_;
     }
 
-    # Add any layers foudn to the mode specification...
+    # Add any layers found to the mode specification...
     $mode .= " $layers";
 
     # Open the source as a filehandle...
@@ -173,7 +174,7 @@ sub slurp {
     }
 
     # Acquire data (working around bug between $/ and in magic ARGV)...
-    my $data = $FH == \*ARGV ? join("",<>) : do { local $/; <$FH> };
+    my $data = refaddr($FH) == \*ARGV ? join("",<>) : do { local $/; <$FH> };
 
     # Prepare input record separator regex...
     my $irs = ref($/)       ? $/
@@ -251,7 +252,7 @@ Perl6::Slurp - Implements the Perl 6 'slurp' built-in
     $str_contents = slurp '<', \$string;
 
 
-    # Slurp a pipe...
+    # Slurp a pipe (not on Windows, alas)...
 
     $str_contents = slurp 'tail -20 $filename |';
     $str_contents = slurp '-|', 'tail', -20, $filename;
@@ -355,8 +356,9 @@ a scalar reference,
 
 =back
 
-converts it to an input stream if necessary, and reads in the entire stream.
-If C<slurp> fails to set up or read the stream, it throws an exception.
+converts it to an input stream (using C<open()> if necessary), and reads
+in the entire stream. If C<slurp> fails to set up or read the stream, it
+throws an exception.
 
 If no data source is specified C<slurp> uses the value of C<$_> as the
 source. If C<$_> is undefined, C<slurp> uses the C<@ARGV> list,
@@ -381,7 +383,8 @@ record separator and returns the resulting list of strings.
 You can set the input record separator (S<< C<< { irs => $your_irs_here}
 >> >>) for the input operation. The separator can be specified as a
 string or a regex. Note that an explicit input record separator has no
-effect in a scalar context, since C<slurp> always reads in everything anyway.
+input-terminating effect in a scalar context; C<slurp> always
+reads in the entire input stream, whatever the C<'irs'> value.
 
 In a list context, changing the separator can change how the input is
 broken up within the list that is returned.
@@ -401,7 +404,7 @@ You can also tell C<slurp> to compute the replacement string on-the-fly
 by specifying a subroutine as the C<chomp> value:
 (S<< C<< { chomp => sub{...} } >> >>). This subroutine is passed the string
 being chomped off, so for example you could squeeze single newlines to a
-single space and multiple conseqcutive newlines to a two newlines with:
+single space and multiple consecutive newlines to a two newlines with:
 
     sub squeeze {
         my ($removed) = @_;
@@ -482,16 +485,22 @@ Use an array instead:
     slurp $filename, [layer1=>1, layer2=>1, etc=>1];
 
 
-=head1 WARNING
+=head1 WARNINGS
 
 The syntax and semantics of Perl 6 is still being finalized
 and consequently is at any time subject to change. That means the
 same caveat applies to this module.
 
+When called with a filename or piped shell command, C<slurp()> uses
+Perl's built- in C<open()> to access the file. This means that it
+is subject to the same platform-specific limitations as C<open()>.
+For example, slurping from piped shell commands may not work 
+under Windows.
+
 
 =head1 DEPENDENCIES
 
-Requires: Perl 5.8.0, Perl6::Export
+Requires: Perl 5.8.0
 
 
 =head1 AUTHOR
